/***************************************************************************//**
 *   @file   AD799x.h
 *   @brief  Header file of AD799x Driver.
 *   @author DNechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 576
*******************************************************************************/

#ifndef _AD799X_H_
#define _AD799X_H_

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "Communication.h"

/******************************************************************************/
/* AD799x                                                                     */
/******************************************************************************/
#define AD799X_ADDRESS          0x28 // I2C address of AD7991 .

/*
 * AD7991, AD7995 and AD7999 defines
 */
#define AD7791_CHANNELS_NO      4
#define AD7795_CHANNELS_NO      4
#define AD7799_CHANNELS_NO      4

#define AD7991_BITS_NO          12
#define AD7995_BITS_NO          10
#define AD7999_BITS_NO          8

#define AD7991_CHANNEL(ch)      ((1 << ch) << 4)
#define AD7995_CHANNEL(ch)      ((1 << ch) << 4)
#define AD7999_CHANNEL(ch)      ((1 << ch) << 4)

#define AD7991_REF_SEL			0x08
#define AD7991_FLTR				0x04
#define AD7991_BIT_TRIAL_DELAY	0x02
#define AD7991_SAMPLE_DELAY		0x01

/*
 * AD7992, AD7993, AD7994, AD7997 and AD7998 defines
 */
#define AD7792_CHANNELS_NO      2
#define AD7793_CHANNELS_NO      4
#define AD7794_CHANNELS_NO      4
#define AD7797_CHANNELS_NO      8
#define AD7798_CHANNELS_NO      8

#define AD7992_BITS_NO          12
#define AD7993_BITS_NO          10
#define AD7994_BITS_NO          12
#define AD7997_BITS_NO          10
#define AD7998_BITS_NO          12

#define AD7992_CHANNEL(ch)      ((1 << ch) << 4)
#define AD7993_CHANNEL(ch)      ((1 << ch) << 4)
#define AD7994_CHANNEL(ch)      ((1 << ch) << 4)
#define AD7997_CHANNEL(ch)      (ch << 4)
#define AD7998_CHANNEL(ch)      (ch << 4)

#define AD7998_FLTR				0x08
#define AD7998_ALERT_EN			0x04
#define AD7998_BUSY_ALERT		0x02
#define AD7998_BUSY_ALERT_POL	0x01

#define AD7998_CONV_RES_REG		0x0
#define AD7998_ALERT_STAT_REG	0x1
#define AD7998_CONF_REG			0x2
#define AD7998_CYCLE_TMR_REG	0x3
#define AD7998_DATALOW_CH1_REG	0x4
#define AD7998_DATAHIGH_CH1_REG	0x5
#define AD7998_HYST_CH1_REG		0x6
#define AD7998_DATALOW_CH2_REG	0x7
#define AD7998_DATAHIGH_CH2_REG	0x8
#define AD7998_HYST_CH2_REG		0x9
#define AD7998_DATALOW_CH3_REG	0xA
#define AD7998_DATAHIGH_CH3_REG	0xB
#define AD7998_HYST_CH3_REG		0xC
#define AD7998_DATALOW_CH4_REG	0xD
#define AD7998_DATAHIGH_CH4_REG	0xE
#define AD7998_HYST_CH4_REG		0xF

#define AD7998_CYC_MASK			0x7
#define AD7998_CYC_DIS			0x0
#define AD7998_CYC_TCONF_32		0x1
#define AD7998_CYC_TCONF_64		0x2
#define AD7998_CYC_TCONF_128	0x3
#define AD7998_CYC_TCONF_256	0x4
#define AD7998_CYC_TCONF_512	0x5
#define AD7998_CYC_TCONF_1024	0x6
#define AD7998_CYC_TCONF_2048	0x7

#define AD7998_ALERT_STAT_CLEAR	0xFF

/*
 * AD7997 and AD7998 defines
 */
#define AD7997_8_READ_SINGLE	0x80
#define AD7997_8_READ_SEQUENCE	0x70

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/

/* Initializes I2C. */
unsigned char AD799x_Init(void);

/* Writes data into the Configuration Register. */
void AD799x_SetRegisterValue(unsigned char registerValue);

/* Reads the High byte and the Low byte of the conversion. */
void AD799x_GetConversionResult(unsigned short* convValue,
                                unsigned char* channel,
							    unsigned char bitsNumber,
                                unsigned char channelsNo);

#endif // _AD799X_H_
